@@ -191,13 +191,22 @@ class Metamist:
         Retrieve sample entries for a dataset, in the context of sample IDs
         and sequencing type.
         """
-        entries: list[dict] = self.seqapi.get_sequences_by_sample_ids(
-            sample_ids, get_latest_sequence_only=False
-        )
-        entries = [seq for seq in entries if str(seq['type']) == sequencing_type]
         entries_by_sid = defaultdict(list)
-        for entry in entries:
-            entries_by_sid[entry['sample_id']].append(entry)
+
+        entries = self.seqapi.get_sequences_by_sample_ids(sample_ids)
+        if isinstance(entries, list):
+            entries_list: list[dict] = entries
+            for entry in entries_list:
+                if str(entry['type']) == sequencing_type:
+                    entries_by_sid[entry['sample_id']].append(entry)
+        else:
+            assert isinstance(entries, dict)
+            entries_dict: dict[str, list[dict]] = entries
+            for sample_id, sample_sequences in entries_dict.items():
+                for seq in sample_sequences:
+                    if str(seq['type']) == sequencing_type:
+                        entries_by_sid[sample_id].append(seq)
+
         return entries_by_sid
 
     def get_participant_entries_by_sid(self, dataset_name: str) -> dict[str, dict]:
@@ -222,11 +231,10 @@ class Metamist:
         for entry in entries:
             pid = entry['external_id']
             if not (sid := sid_by_pid.get(pid)):
-                raise MetamistError(
-                    f'papi.get_participants returned participant that was not returned '
-                    f'by papi.get_external_participant_id_to_internal_sample_id: '
-                    f'{entry}'
-                )
+                # This is an expected behaviour: dummy participant entries might be
+                # created to fill in the PED data. We should just ignore participants
+                # with no associated samples.
+                continue
             participant_entry_by_sid[sid] = entry
         return participant_entry_by_sid
 
@@ -467,12 +475,29 @@ class Metamist:
 
         entries = self.fapi.get_families(metamist_proj)
         family_ids = [entry['id'] for entry in entries]
-        ped_entries = self.fapi.get_pedigree(
-            internal_family_ids=family_ids,
-            export_type='json',
-            project=metamist_proj,
-            replace_with_participant_external_ids=True,
-        )
+
+        # Since `fapi.get_pedigree` is a GET endpoint, it is limited by the length of
+        # the request string. It would stall with the number of families above ~600.
+        # To mitigate this, we split the input into chunks. 500 families should be
+        # a safe number of families in one chunk.
+        def _chunks(seq, size):
+            return (seq[pos : pos + size] for pos in range(0, len(seq), size))
+
+        ped_entries = []
+        chunk_size = 500
+        for i, fam_ids_chunk in enumerate(_chunks(family_ids, chunk_size)):
+            logging.info(
+                f'Running fapi.get_pedigree on families #{i * chunk_size}..'
+                f'{i * chunk_size + 1 + len(fam_ids_chunk)} (out of {len(family_ids)})'
+            )
+            ped_entries.extend(
+                self.fapi.get_pedigree(
+                    internal_family_ids=fam_ids_chunk,
+                    export_type='json',
+                    project=metamist_proj,
+                    replace_with_participant_external_ids=True,
+                )
+            )
 
         return ped_entries
 
@@ -493,7 +518,11 @@ class Sequence:
     alignment_input: AlignmentInput | None = None
 
     @staticmethod
-    def parse(data: dict, check_existence: bool = False) -> 'Sequence':
+    def parse(
+        data: dict,
+        check_existence: bool = False,
+        parse_reads: bool = True,
+    ) -> 'Sequence':
         """
         Create from a dictionary.
         """
@@ -513,25 +542,23 @@ class Sequence:
             meta=data['meta'],
             sequencing_type=sequencing_type,
         )
-        alignment_input = Sequence._parse_reads(
-            sample_id=sample_id,
-            meta=data['meta'],
-            check_existence=check_existence,
-        )
-        assert alignment_input, (sample_id, data)
-        mm_seq.alignment_input = alignment_input
+        if parse_reads:
+            mm_seq.alignment_input = Sequence.parse_reads(
+                sample_id=sample_id,
+                meta=data['meta'],
+                check_existence=check_existence,
+            )
         return mm_seq
 
     @staticmethod
-    def _parse_reads(  # pylint: disable=too-many-return-statements
+    def parse_reads(  # pylint: disable=too-many-return-statements
         sample_id: str,
         meta: dict,
         check_existence: bool,
-    ) -> AlignmentInput | None:
+    ) -> AlignmentInput:
         """
         Parse a AlignmentInput object from the meta dictionary.
-
-        @param check_existence: check if fastq/crams exist on buckets.
+        `check_existence`: check if fastq/crams exist on buckets.
         Default value is pulled from self.metamist and can be overridden.
         """
         reads_data = meta.get('reads')
@@ -539,38 +566,34 @@ class Sequence:
         reference_assembly = meta.get('reference_assembly', {}).get('location')
 
         if not reads_data:
-            logging.error(f'{sample_id}: no "meta/reads" field in meta')
-            return None
+            raise MetamistError(f'{sample_id}: no "meta/reads" field in meta')
         if not reads_type:
-            logging.error(f'{sample_id}: no "meta/reads_type" field in meta')
-            return None
+            raise MetamistError(f'{sample_id}: no "meta/reads_type" field in meta')
         supported_types = ('fastq', 'bam', 'cram')
         if reads_type not in supported_types:
-            logging.error(
+            raise MetamistError(
                 f'{sample_id}: ERROR: "reads_type" is expected to be one of '
                 f'{supported_types}'
             )
-            return None
 
         if reads_type in ('bam', 'cram'):
             if len(reads_data) > 1:
-                logging.error(f'{sample_id}: supporting only single bam/cram input')
-                return None
+                raise MetamistError(
+                    f'{sample_id}: supporting only single bam/cram input'
+                )
 
             location = reads_data[0]['location']
             if not (location.endswith('.cram') or location.endswith('.bam')):
-                logging.error(
+                raise MetamistError(
                     f'{sample_id}: ERROR: expected the file to have an extension '
                     f'.cram or .bam, got: {location}'
                 )
-                return None
             if get_config()['workflow']['access_level'] == 'test':
                 location = location.replace('-main-upload/', '-test-upload/')
             if check_existence and not exists(location):
-                logging.error(
+                raise MetamistError(
                     f'{sample_id}: ERROR: index file does not exist: {location}'
                 )
-                return None
 
             # Index:
             index_location = None
@@ -582,7 +605,7 @@ class Sequence:
                     or location.endswith('.bai')
                     and not index_location.endswith('.bai')
                 ):
-                    logging.error(
+                    raise MetamistError(
                         f'{sample_id}: ERROR: expected the index file to have an extension '
                         f'.crai or .bai, got: {index_location}'
                     )
@@ -591,10 +614,9 @@ class Sequence:
                         '-main-upload/', '-test-upload/'
                     )
                 if check_existence and not exists(index_location):
-                    logging.error(
+                    raise MetamistError(
                         f'{sample_id}: ERROR: index file does not exist: {index_location}'
                     )
-                    return None
 
             if location.endswith('.cram'):
                 return CramPath(
@@ -624,17 +646,15 @@ class Sequence:
                         '-main-upload/', '-test-upload/'
                     )
                 if check_existence and not exists(lane_pair[0]['location']):
-                    logging.error(
+                    raise MetamistError(
                         f'{sample_id}: ERROR: read 1 file does not exist: '
                         f'{lane_pair[0]["location"]}'
                     )
-                    return None
                 if check_existence and not exists(lane_pair[1]['location']):
-                    logging.error(
+                    raise MetamistError(
                         f'{sample_id}: ERROR: read 2 file does not exist: '
                         f'{lane_pair[1]["location"]}'
                     )
-                    return None
 
                 fastq_pairs.append(
                     FastqPair(
